@@ -242,12 +242,12 @@ auto NodeManager::registerNode(pw_registry* registry, uint32_t id, const char* t
 
 // Static callback implementations
 void NodeManager::onNodeInfo(void* object, const pw_node_info* info) {
-  if (NodeManager::exiting) {
+  auto* const nd = static_cast<NodeData*>(object);
+
+  if (NodeManager::exiting || nd->nd_info == nullptr) {
     return;
   }
 
-  auto* const nd = static_cast<NodeData*>(object);
-
   auto* const nm = nd->nm;
 
   // Check if the node has to be removed
@@ -330,13 +330,13 @@ void NodeManager::onNodeInfo(void* object, const pw_node_info* info) {
   }
 
   if (ignore_node) {
+    // Just in case the previous tests returned false in the first callback iteration
+    nm->model_nodes.remove_by_serial(nd->nd_info->serial);
+
     if (nd->proxy != nullptr) {
       pw_proxy_destroy(nd->proxy);
     }
 
-    // Just in case the previous tests returned false in the first callback iteration
-    nm->model_nodes.remove_by_serial(nd->nd_info->serial);
-
     return;
   }
 
@@ -400,19 +400,6 @@ void NodeManager::onNodeInfo(void* object, const pw_node_info* info) {
 
   util::spa_dict_get_num(info->props, PW_KEY_DEVICE_ID, nd->nd_info->device_id);
 
-  bool deviceProfileChanged = false;
-
-  if (const auto* device_profile_name = spa_dict_lookup(info->props, "device.profile.name")) {
-    if (nd->nd_info->device_profile_name != device_profile_name) {
-      nd->nd_info->device_profile_name = device_profile_name;
-      deviceProfileChanged = true;
-    }
-  }
-
-  if (const auto* device_profile_description = spa_dict_lookup(info->props, "device.profile.description")) {
-    nd->nd_info->device_profile_description = device_profile_description;
-  }
-
   // sometimes PipeWire destroys the pointer before signal_idle is called,
   // therefore we make a copy
 
@@ -479,6 +466,12 @@ void NodeManager::onNodeInfo(void* object, const pw_node_info* info) {
   } else {
     nd->nd_info->is_blocklisted = nm->model_nodes.get_node_by_id(nd->nd_info->id).is_blocklisted;
 
+    /*
+     * This information is updated elsewhere through the device object event
+     */
+    nd->nd_info->device_route_name = nm->model_nodes.get_node_by_id(nd->nd_info->id).device_route_name;
+    nd->nd_info->device_route_description = nm->model_nodes.get_node_by_id(nd->nd_info->id).device_route_description;
+
     nm->model_nodes.update_info(*nd->nd_info);
 
     if (nd->nd_info->media_class == tags::pipewire::media_class::output_stream) {
@@ -488,16 +481,6 @@ void NodeManager::onNodeInfo(void* object, const pw_node_info* info) {
     }
   }
 
-  if (deviceProfileChanged) {
-    if (nd->nd_info->media_class == tags::pipewire::media_class::source &&
-        nd->nd_info->name != tags::pipewire::ee_source_name) {
-      Q_EMIT nm->sourceProfileNameChanged(*nd->nd_info);
-    } else if (nd->nd_info->media_class == tags::pipewire::media_class::sink &&
-               nd->nd_info->name != tags::pipewire::ee_sink_name) {
-      Q_EMIT nm->sinkProfileNameChanged(*nd->nd_info);
-    }
-  }
-
   if ((info->change_mask & PW_NODE_CHANGE_MASK_PARAMS) != 0U) {
     auto params = std::span(info->params, info->n_params);
 
